@@ -35,7 +35,7 @@ from .modules import Module
 class Build:
 
     def __init__(self, opts, package=None, dsc=None, debopts=None,
-                 distribution=None, extrabd=None, origin=None):
+                 distribution=None, extrabd=None, origin=None, uploader=None):
         (self.opts, self.rtopts, self.conffile) = opts
         self.package = package
         self.dscfile = dsc
@@ -48,7 +48,7 @@ class Build:
         self.files = set()
         self.packagedir = self.opts.get('default', 'packagedir')
         self.full = False
-        self.uploader = None
+        self.uploader = uploader
 
     def build(self):
         if self.full:
@@ -107,22 +107,27 @@ class Build:
         with open(os.devnull, 'w') as fd:
             try:
                 debug(_('Launching %s') % builder)
-                call([builder, '--build', '--override-config',
-                     base, '%s/%s' % (self.buildpath, self.distribution),
-                     '--architecture', architecture,
-                     '--logfile', '%s/pool/%s/%s.buildlog' %
-                     (self.buildpath, packageversion, packageversion),
-                     '--buildplace', '%s/build' % self.buildpath,
-                     '--buildresult', '%s/pool/%s' %
-                     (self.buildpath, packageversion),
-                     '--aptcache', '%s/aptcache' % self.buildpath,
-                     '--debbuildopts', '%s' % debopts,
-                     '--hookdir', self.opts.get('default', 'pbuilderhooks'),
-                     '--extrapackages', '%s' % self.get_extra_builddeps(),
-                     '--configfile', self.configfile, self.dscfile],
-                     stdout=fd, stderr=fd)
+                result = call([builder, '--build', '--override-config',
+                               base, '%s/%s' % (self.buildpath,
+                                                self.distribution),
+                               '--architecture', architecture,
+                               '--logfile', '%s/pool/%s/%s.buildlog' %
+                               (self.buildpath, packageversion,
+                                packageversion),
+                               '--buildplace', '%s/build' % self.buildpath,
+                               '--buildresult', '%s/pool/%s' %
+                               (self.buildpath, packageversion),
+                               '--aptcache', '%s/aptcache' % self.buildpath,
+                               '--debbuildopts', '%s' % debopts,
+                               '--hookdir', self.opts.get('default',
+                                                          'pbuilderhooks'),
+                               '--extrapackages',
+                               '%s' % self.get_extra_builddeps(),
+                               '--configfile', self.configfile, self.dscfile],
+                              stdout=fd, stderr=fd)
             except OSError:
                 error(_('Unable to launch %s') % builder)
+                result = -1
         debug(_('Post-build hooks launched'))
         mod.execute_hook('post_build', {'cfg': self.configfile,
                                         'directory': self.buildpath,
@@ -131,7 +136,8 @@ class Build:
                                         'dsc': self.dscfile,
                                         'opts': self.opts,
                                         'package': packageversion,
-                                        'uploader': uploader_email})
+                                        'uploader': uploader_email,
+                                        'success': result == 0})
         debug(_('Post-build hooks finished'))
         self.remove_files()
         info(_('Build of %s complete') % os.path.basename(self.dscfile))
@@ -261,7 +267,7 @@ class Build:
         remote_sha.update(remote)
         try:
             with open(gpgfile, 'r') as fd:
-                gpgfile_sha.update(fd.read())
+                gpgfile_sha.update(fd.read().encode('utf-8'))
         except OSError:
             self.cmd = 'create'
             debug(_('%s chroot must be created') % distribution)
@@ -306,7 +312,7 @@ class Build:
             exit(2)
         for elem in conf:
             try:
-                if not elem in self.distopts or not self.distopts[elem]:
+                if elem not in self.distopts or not self.distopts[elem]:
                     self.distopts[elem] = findall(conf[elem][0], data)[0]
             except IndexError:
                 error(_('Please set %(parm)s in %s(conf)s') %
@@ -346,6 +352,7 @@ class Build:
                                         'distribution': self.distribution,
                                         'architecture': architecture,
                                         'cmd': self.cmd})
+        debug(_('Pre-chroot maintenance hooks finished'))
         for d in ('aptcache', 'build', 'logs', 'pool'):
             if not os.path.exists(os.path.join(self.buildpath, d)):
                 os.mkdir(os.path.join(self.buildpath, d))
@@ -354,46 +361,44 @@ class Build:
         else:
             base = '--basetgz'
         with open(os.devnull, 'w') as fd:
+            params = {'cfg': self.configfile,
+                      'directory': self.buildpath,
+                      'opts': self.opts,
+                      'distribution': self.distribution,
+                      'architecture': architecture,
+                      'cmd': self.cmd,
+                      'success': True}
             try:
                 debug(_('Launching %(builder)s %(cmd)s')
                       % {'builder': builder, 'cmd': self.cmd})
                 if call([builder, '--%s' % self.cmd, '--override-config',
-                        base, '%s/%s' % (self.buildpath, self.distribution),
-                        '--buildplace', '%s/build' % self.buildpath,
-                        '--aptcache', '%s/aptcache' % self.buildpath,
-                        '--architecture', architecture,
-                        '--logfile', '%s/logs/%s.%s' %
-                        (self.buildpath, self.cmd, strftime('%Y%m%d_%H%M%S')),
-                        '--configfile', '%s' % self.configfile,
-                        '--debootstrap', debootstrap],
+                         base, '%s/%s' % (self.buildpath, self.distribution),
+                         '--buildplace', '%s/build' % self.buildpath,
+                         '--aptcache', '%s/aptcache' % self.buildpath,
+                         '--autocleanaptcache',
+                         '--architecture', architecture,
+                         '--logfile', '%s/logs/%s.%s' %
+                         (self.buildpath, self.cmd, strftime('%Y%m%d_%H%M%S')),
+                         '--configfile', '%s' % self.configfile,
+                         '--debootstrap', debootstrap],
                         stdout=fd, stderr=fd):
-                    debug(_('Post-chroot maintenance hooks launched'))
-                    mod.execute_hook('post_chroot', {'cfg': self.configfile,
-                                     'directory': self.buildpath,
-                                     'opts': self.opts,
-                                     'distribution': self.distribution,
-                                     'architecture': architecture,
-                                     'cmd': self.cmd, 'success': False})
                     error(_('%(builder)s %(cmd)s failed') %
                           {'builder': builder, 'cmd': self.cmd})
+                    debug(_('Post-chroot maintenance hooks launched'))
+                    params['success'] = False
+                    mod.execute_hook('post_chroot', params)
+                    debug(_('Post-chroot maintenance hooks finished'))
                     raise RuntimeError
             except OSError:
-                debug(_('Post-chroot maintenance hooks launched'))
-                mod.execute_hook('post_chroot', {'cfg': self.configfile,
-                                 'directory': self.buildpath,
-                                 'opts': self.opts,
-                                 'distribution': self.distribution,
-                                 'architecture': architecture,
-                                 'cmd': self.cmd, 'success': False})
                 error(_('Unable to launch %s') % builder)
+                debug(_('Post-chroot maintenance hooks launched'))
+                params['success'] = False
+                mod.execute_hook('post_chroot', params)
+                debug(_('Post-chroot maintenance hooks finished'))
                 raise RuntimeError
         debug(_('Post-chroot maintenance hooks launched'))
-        mod.execute_hook('post_chroot', {'cfg': self.configfile,
-                                         'directory': self.buildpath,
-                                         'opts': self.opts,
-                                         'distribution': self.distribution,
-                                         'architecture': architecture,
-                                         'cmd': self.cmd, 'success': True})
+        mod.execute_hook('post_chroot', params)
+        debug(_('Post-chroot maintenance hooks finished'))
 
     def remove_files(self):
         for pkgfile in self.files:
