@@ -36,7 +36,7 @@ class Debomatic(Process):
         self.daemonize = True
         self.setlog('%(levelname)s: %(message)s')
         self.conffile = None
-        self.configvers = '012a'
+        self.configvers = '013a'
         self.opts = ConfigParser()
         self.rtopts = ConfigParser()
         parser = ArgumentParser()
@@ -60,14 +60,13 @@ class Debomatic(Process):
             error(_('Unable to access %s directory') % self.packagedir)
             exit(1)
         self.pool = ThreadPool(self.opts.getint('default', 'maxbuilds'))
-        self.commandpool = ThreadPool()
         self.logfile = self.opts.get('default', 'logfile')
-        self.mod_sys = Module((self.opts, self.rtopts, self.conffile))
         if args.quit_process:
             self.shutdown()
             exit()
         self.setlog('%(levelname)s: %(message)s',
                     self.opts.get('default', 'loglevel'))
+        self.mod_sys = Module((self.opts, self.rtopts, self.conffile))
         debug(_('Startup hooks launched'))
         self.mod_sys.execute_hook('on_start', {})
         debug(_('Startup hooks finished'))
@@ -152,8 +151,7 @@ class Debomatic(Process):
             elif filename.endswith('.commands'):
                 c = Command((self.opts, self.rtopts, self.conffile),
                             self.pool, filename)
-                self.commandpool.schedule(c.process_command)
-                debug(_('Thread for %s scheduled') % filename)
+                c.process_command()
 
     def setlog(self, fmt, level='info'):
         loglevels = {'error': ERROR,
