@@ -25,6 +25,7 @@ from hashlib import sha256
 from logging import basicConfig as log, debug, error, getLogger, info
 from signal import signal, SIGINT, SIGTERM
 from sys import stdin, stdout, stderr
+from time import sleep
 
 
 class Process:
@@ -83,8 +84,7 @@ class Process:
 
     def _quit(self, signum=None, frame=None):
         info(_('Waiting for threads to complete...'))
-        self.pool.wait()
-        self.commandpool.wait()
+        self.pool.shutdown()
         debug(_('Shutdown hooks launched'))
         self.mod_sys.execute_hook('on_quit', {})
         debug(_('Shutdown hooks finished'))
@@ -142,6 +142,34 @@ class Process:
         self.launcher()
 
 
+class ModulePool:
+
+    def __init__(self, workers=1):
+        self._jobs = {}
+        self._pool = ThreadPoolExecutor(workers)
+
+    def _launch(self, func, hook, dependencies):
+        if dependencies:
+            for dependency in dependencies:
+                while True:
+                    if dependency in self._jobs.keys():
+                        self._jobs[dependency].result()
+                        break
+                    else:
+                        sleep(0.1)
+        func(hook)
+
+    def schedule(self, func, hook):
+        innerfunc, args, module, hookname, dependencies = hook
+        job = self._pool.submit(self._launch, func, hook, dependencies)
+        self._jobs[module] = job
+
+    def shutdown(self):
+        for job in as_completed([self._jobs[j] for j in self._jobs]):
+            job.result()
+        self._pool.shutdown()
+
+
 class ThreadPool:
 
     def __init__(self, workers=1):
@@ -153,12 +181,19 @@ class ThreadPool:
             self._jobs.remove(job)
         except ValueError:
             pass
+        try:
+            e = job.exception()
+            if e:
+                raise e
+        except Exception as e:
+            debug(str(e), exc_info=True)
 
     def schedule(self, func):
         job = self._pool.submit(func)
         job.add_done_callback(self._finish)
         self._jobs.append(job)
 
-    def wait(self):
+    def shutdown(self):
         for job in as_completed(self._jobs):
             job.result()
+        self._pool.shutdown()
